package cn.com.ty.lift.enterprise.oa.controller;

import cn.com.ty.lift.common.model.CountPage;
import cn.com.ty.lift.common.verify.Ver;
import cn.com.ty.lift.common.verify.Verifier;
import cn.com.ty.lift.common.verify.Verify;
import cn.com.ty.lift.enterprise.oa.dto.LiftCertificateRequest;
import cn.com.ty.lift.enterprise.oa.dto.LiftCertificateResponse;
import cn.com.ty.lift.enterprise.oa.entity.LiftCertificate;
import cn.com.ty.lift.enterprise.oa.service.LiftCertificateService;
import cn.com.xwy.boot.web.dto.RestResponse;
import com.baomidou.mybatisplus.core.metadata.IPage;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;


/**
 * <p>
 *      操作证 前端控制器
 * </p>
 *
 * @author wcz
 * @since 2019-12-04
 */
@Slf4j
@AllArgsConstructor
@RestController
@RequestMapping("/oa/liftCertificate")
public class LiftCertificateController {

    private LiftCertificateService liftCertificateService;

    /**
     * 根据id查找
     * @param request LiftCertificateRequest
     * @return RestResponse
     */
    @PostMapping("findOne")
    @Verifier(fields = {"id"})
    public RestResponse findOne(@Ver @RequestBody LiftCertificateRequest request) {
        LiftCertificateResponse result = liftCertificateService.infoById(request);
        return RestResponse.success(result);
    }

    /**
     * 根据条件查询
     * @param request LiftCertificateRequest
     * @return RestResponse
     */
    @PostMapping("list")
    @Verifier(fields = "mtCompanyId")
    public RestResponse list(@Ver @RequestBody LiftCertificateRequest request) {
        IPage<LiftCertificateResponse> pages = liftCertificateService.pageByCondition(request);
        long count = liftCertificateService.countByCondition(request);
        return RestResponse.success(CountPage.getCountPage(count, pages));
    }

    /**
     * 更新操作证信息
     * @param entity LiftCertificate
     * @return RestResponse
     */
    @PostMapping("modify")
    @Verifier(fields = {"id"})
    public RestResponse modify(@Valid @RequestBody LiftCertificate entity) {
        Long id = entity.getId();
        Long ownerId = entity.getOwnerId();
        Long mtCompanyId = entity.getMtCompanyId();
        LiftCertificate certificate = liftCertificateService.findByUserAndMtCompany(id, ownerId, mtCompanyId);
        Verify.notNull(certificate,Verify.LiftCert.CertNotExist);
        boolean result = liftCertificateService.updateById(entity);
        return RestResponse.success(result);
    }

    /**
     * 操作证审核
     * @param request LiftCertificateRequest
     * @return RestResponse
     */
    @PostMapping("audit")
    @Verifier(fields = {"id"})
    public RestResponse audit(@Ver @RequestBody LiftCertificateRequest request) {
        //0：无证，1：待审核，2：审核未通过，3：审核通过，4：超期
        LiftCertificate liftCertificate = liftCertificateService.getById(request.getId());
        Verify.notNull(liftCertificate);
        Verify.isTrue(Verify.LiftCert.toAudit(liftCertificate.getStatus()), Verify.LiftCert.MustToAudit);
        int status = request.isPass() ? Verify.LiftCert.Status_AuditPass : Verify.LiftCert.Status_AuditFail;
        liftCertificate.setStatus(status);
        boolean result = liftCertificateService.saveOrUpdate(liftCertificate);
        return RestResponse.success(result);
    }

    /**
     * 新增操作证
     * @param entity LiftCertificate
     * @return RestResponse
     */
    @PostMapping("add")
    public RestResponse add(@Valid @RequestBody LiftCertificate entity) {
        Long ownerId = entity.getOwnerId();
        Long mtCompanyId = entity.getMtCompanyId();

        int count = liftCertificateService.countByUserAndMtCompany(ownerId, mtCompanyId);
        Verify.nogt0(count, Verify.LiftCert.CertHadExist);

        entity.setStatus(Verify.LiftCert.Status_ToAudit);

        boolean result = liftCertificateService.saveOrUpdate(entity);
        return RestResponse.success(result);

    }
    @PostMapping("findByUser")
    @Verifier(fields = {"ownerId","mtCompanyId"})
    public RestResponse findByUser(@Ver @RequestBody LiftCertificateRequest request){
        LiftCertificate entity = liftCertificateService.findByUserAndMtCompany(request.getId(), request.getOwnerId(), request.getMtCompanyId());
        return RestResponse.success(entity);
    }
}
